package Monitoring::GLPlugin::SNMP::MibsAndOids::LIEBERTGPCONDITIONSMIB;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'LIEBERT-GP-CONDITIONS-MIB'} = {
  url => '',
  name => 'LIEBERT-GP-CONDITIONS-MIB',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'LIEBERT-GP-CONDITIONS-MIB'} = '1.3.6.1.4.1.476.1.42.3.2';

$Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS-MIB'} = {
  liebertGlobalProductsConditionsModule => '1.3.6.1.4.1.476.1.42.1.3.1',
  lgpConditionsWellKnown => '1.3.6.1.4.1.476.1.42.3.2.1',
  lgpConditionHighTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.1',
  lgpConditionLowTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.2',
  lgpConditionHighHumidity => '1.3.6.1.4.1.476.1.42.3.2.1.3',
  lgpConditionLowHumidity => '1.3.6.1.4.1.476.1.42.3.2.1.4',
  lgpConditionLossOfAirflow => '1.3.6.1.4.1.476.1.42.3.2.1.5',
  lgpConditionLossOfAirflow1 => '1.3.6.1.4.1.476.1.42.3.2.1.5.1',
  lgpConditionLossOfAirflow2 => '1.3.6.1.4.1.476.1.42.3.2.1.5.2',
  lgpConditionLossOfAirflowBlower1 => '1.3.6.1.4.1.476.1.42.3.2.1.5.3',
  lgpConditionLossOfAirflowAllBlowers => '1.3.6.1.4.1.476.1.42.3.2.1.5.4',
  lgpConditionChangeFilter => '1.3.6.1.4.1.476.1.42.3.2.1.6',
  lgpConditionCompressorHighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7',
  lgpConditionCompressor1HighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.1',
  lgpConditionCompressor1AHighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.1.1',
  lgpConditionCompressor1BHighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.1.2',
  lgpConditionCompressor2HighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.2',
  lgpConditionCompressor2AHighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.2.1',
  lgpConditionCompressor2BHighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.2.2',
  lgpConditionCompressor3HighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.3',
  lgpConditionCompressor4HighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.4',
  lgpConditionCompressorOverload => '1.3.6.1.4.1.476.1.42.3.2.1.8',
  lgpConditionCompressor1Overload => '1.3.6.1.4.1.476.1.42.3.2.1.8.1',
  lgpConditionCompressor2Overload => '1.3.6.1.4.1.476.1.42.3.2.1.8.2',
  lgpConditionCompressorShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9',
  lgpConditionCompressor1ShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9.1',
  lgpConditionCompressor1AShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9.1.1',
  lgpConditionCompressor1BShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9.1.2',
  lgpConditionCompressor2ShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9.2',
  lgpConditionCompressor2AShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9.2.1',
  lgpConditionCompressor2BShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9.2.2',
  lgpConditionCompressorLowSuctionPressure => '1.3.6.1.4.1.476.1.42.3.2.1.10',
  lgpConditionCompressor1LowSuctionPressure => '1.3.6.1.4.1.476.1.42.3.2.1.10.1',
  lgpConditionCompressor2LowSuctionPressure => '1.3.6.1.4.1.476.1.42.3.2.1.10.2',
  lgpConditionMainFanOverLoad => '1.3.6.1.4.1.476.1.42.3.2.1.11',
  lgpConditionManualOverride => '1.3.6.1.4.1.476.1.42.3.2.1.12',
  lgpConditionStandbyGlycoolPumpOn => '1.3.6.1.4.1.476.1.42.3.2.1.13',
  lgpConditionWaterUnderFloor => '1.3.6.1.4.1.476.1.42.3.2.1.14',
  lgpConditionHumidifierProblem => '1.3.6.1.4.1.476.1.42.3.2.1.15',
  lgpConditionLowWaterInHumidifier => '1.3.6.1.4.1.476.1.42.3.2.1.16',
  lgpConditionSmokeDetected => '1.3.6.1.4.1.476.1.42.3.2.1.17',
  lgpConditionLowWaterFlow => '1.3.6.1.4.1.476.1.42.3.2.1.18',
  lgpConditionLostPower => '1.3.6.1.4.1.476.1.42.3.2.1.19',
  lgpGeneralFault => '1.3.6.1.4.1.476.1.42.3.2.1.20',
  lgpConditionLocalAlarm => '1.3.6.1.4.1.476.1.42.3.2.1.21',
  lgpConditionLocalAlarm1 => '1.3.6.1.4.1.476.1.42.3.2.1.21.1',
  lgpConditionLocalAlarm2 => '1.3.6.1.4.1.476.1.42.3.2.1.21.2',
  lgpConditionLocalAlarm3 => '1.3.6.1.4.1.476.1.42.3.2.1.21.3',
  lgpConditionLocalAlarm4 => '1.3.6.1.4.1.476.1.42.3.2.1.21.4',
  lgpConditionLocalAlarm5 => '1.3.6.1.4.1.476.1.42.3.2.1.21.5',
  lgpConditionLocalAlarm6 => '1.3.6.1.4.1.476.1.42.3.2.1.21.6',
  lgpConditionLocalAlarm7 => '1.3.6.1.4.1.476.1.42.3.2.1.21.7',
  lgpConditionLocalAlarm8 => '1.3.6.1.4.1.476.1.42.3.2.1.21.8',
  lgpConditionStandbyUnitOn => '1.3.6.1.4.1.476.1.42.3.2.1.22',
  lgpConditionCompressorLowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23',
  lgpConditionCompressor1LowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23.1',
  lgpConditionTandemCompressorCircuit1LowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23.1.1',
  lgpConditionCompressor2LowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23.2',
  lgpConditionTandemCompressorCircuit2LowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23.2.1',
  lgpConditionCompressor3LowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23.3',
  lgpConditionCompressor4LowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23.4',
  lgpConditionHighWaterInPan => '1.3.6.1.4.1.476.1.42.3.2.1.24',
  lgpConditionFaultySensor => '1.3.6.1.4.1.476.1.42.3.2.1.25',
  lgpConditionServiceCooling => '1.3.6.1.4.1.476.1.42.3.2.1.26',
  lgpConditionServiceHumidifier => '1.3.6.1.4.1.476.1.42.3.2.1.27',
  lgpConditionSystemControlBatteryLow => '1.3.6.1.4.1.476.1.42.3.2.1.28',
  lgpConditionGroundSystemFault => '1.3.6.1.4.1.476.1.42.3.2.1.29',
  lgpConditionGroundFailure => '1.3.6.1.4.1.476.1.42.3.2.1.30',
  lgpConditionSecurityBreach => '1.3.6.1.4.1.476.1.42.3.2.1.31',
  lgpConditionEmergencyShutdown => '1.3.6.1.4.1.476.1.42.3.2.1.32',
  lgpConditionOnBypass => '1.3.6.1.4.1.476.1.42.3.2.1.33',
  lgpConditionLoadOnBypass => '1.3.6.1.4.1.476.1.42.3.2.1.33.1',
  lgpConditionLoadOnMaintenceBypass => '1.3.6.1.4.1.476.1.42.3.2.1.33.2',
  lgpConditionParallelSysLoadOnBypass => '1.3.6.1.4.1.476.1.42.3.2.1.33.3',
  lgpConditionLoadOnBypassByImpact => '1.3.6.1.4.1.476.1.42.3.2.1.33.4',
  lgpConditionLoadTransferedToBypass => '1.3.6.1.4.1.476.1.42.3.2.1.33.5',
  lgpConditionEmergencyTransferToBypass => '1.3.6.1.4.1.476.1.42.3.2.1.33.6',
  lgpConditionOutputToLoadVoltTHD => '1.3.6.1.4.1.476.1.42.3.2.1.34',
  lgpConditionLogicFailure => '1.3.6.1.4.1.476.1.42.3.2.1.35',
  lgpConditionPowerSupplyFault => '1.3.6.1.4.1.476.1.42.3.2.1.36',
  lgpConditionPowerSupply1Fault => '1.3.6.1.4.1.476.1.42.3.2.1.36.1',
  lgpConditionPowerSupply2Fault => '1.3.6.1.4.1.476.1.42.3.2.1.36.2',
  lgpConditionPowerSupplyFailure => '1.3.6.1.4.1.476.1.42.3.2.1.37',
  lgpConditionPowerSupply1Failure => '1.3.6.1.4.1.476.1.42.3.2.1.37.1',
  lgpConditionPowerSupply2Failure => '1.3.6.1.4.1.476.1.42.3.2.1.37.2',
  lgpConditionSource1PowerSupplyInputFailure => '1.3.6.1.4.1.476.1.42.3.2.1.37.3',
  lgpConditionSource2PowerSupplyInputFailure => '1.3.6.1.4.1.476.1.42.3.2.1.37.4',
  lgpConditionPowerSupplyLogicFailure => '1.3.6.1.4.1.476.1.42.3.2.1.37.5',
  lgpConditionCompressorPowerSupplyFailure => '1.3.6.1.4.1.476.1.42.3.2.1.37.6',
  lgpConditionOverVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.38',
  lgpConditionSource1OverVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.38.1',
  lgpConditionSource2OverVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.38.2',
  lgpConditionOutputToLoadOverVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.38.3',
  lgpConditionInputOverVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.38.4',
  lgpConditionBypassOverVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.38.5',
  lgpConditionBypassOverVoltageFailure => '1.3.6.1.4.1.476.1.42.3.2.1.38.6',
  lgpConditionBatteryOverVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.38.7',
  lgpConditionDcBusOverVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.38.8',
  lgpConditionDcBus1OverVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.38.8.1',
  lgpConditionDcBus2OverVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.38.8.2',
  lgpConditionDcBus1OverVoltageFailure => '1.3.6.1.4.1.476.1.42.3.2.1.38.8.3',
  lgpConditionDcBus2OverVoltageFailure => '1.3.6.1.4.1.476.1.42.3.2.1.38.8.4',
  lgpConditionUnderVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.39',
  lgpConditionSource1UnderVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.39.1',
  lgpConditionSource2UnderVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.39.2',
  lgpConditionOutputToLoadUnderVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.39.3',
  lgpConditionSource1UnderVoltageRMS => '1.3.6.1.4.1.476.1.42.3.2.1.39.4',
  lgpConditionSource2UnderVoltageRMS => '1.3.6.1.4.1.476.1.42.3.2.1.39.5',
  lgpConditionInputUnderVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.39.6',
  lgpConditionBypassUnderVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.39.7',
  lgpConditionBypassUnderVoltageFailure => '1.3.6.1.4.1.476.1.42.3.2.1.39.8',
  lgpConditionBatteryUnderVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.39.9',
  lgpConditionDcBusUnderVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.39.10',
  lgpConditionDcBus1UnderVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.39.10.1',
  lgpConditionDcBus2UnderVoltage => '1.3.6.1.4.1.476.1.42.3.2.1.39.10.2',
  lgpConditionDcBus1UnderVoltageFailure => '1.3.6.1.4.1.476.1.42.3.2.1.39.10.3',
  lgpConditionDcBus2UnderVoltageFailure => '1.3.6.1.4.1.476.1.42.3.2.1.39.10.4',
  lgpConditionOverload => '1.3.6.1.4.1.476.1.42.3.2.1.40',
  lgpConditionSource1Overload => '1.3.6.1.4.1.476.1.42.3.2.1.40.1',
  lgpConditionSystemOverload => '1.3.6.1.4.1.476.1.42.3.2.1.40.2',
  lgpConditionSource1PeakCurrentOverLoad => '1.3.6.1.4.1.476.1.42.3.2.1.40.3',
  lgpConditionSource2PeakCurrentOverLoad => '1.3.6.1.4.1.476.1.42.3.2.1.40.4',
  lgpConditionOutputToLoadOverLimit => '1.3.6.1.4.1.476.1.42.3.2.1.40.5',
  lgpConditionOutputToLoadOverload => '1.3.6.1.4.1.476.1.42.3.2.1.40.6',
  lgpConditionParallelSysOverload => '1.3.6.1.4.1.476.1.42.3.2.1.40.7',
  lgpConditionBypassCurrentOverload => '1.3.6.1.4.1.476.1.42.3.2.1.40.8',
  lgpConditionBypassCurrentOverloadPhsA => '1.3.6.1.4.1.476.1.42.3.2.1.40.8.1',
  lgpConditionBypassCurrentOverloadPhsB => '1.3.6.1.4.1.476.1.42.3.2.1.40.8.2',
  lgpConditionBypassCurrentOverloadPhsC => '1.3.6.1.4.1.476.1.42.3.2.1.40.8.3',
  lgpConditionScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41',
  lgpConditionSource1ScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41.1',
  lgpConditionSource2ScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41.2',
  lgpConditionBypassScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41.3',
  lgpConditionInvStaticSwScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41.4',
  lgpConditionSource1NeutralScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41.5',
  lgpConditionSource2NeutralScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41.6',
  lgpConditionScrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.42',
  lgpConditionSource1ScrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.42.1',
  lgpConditionSource2ScrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.42.2',
  lgpConditionBypassScrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.42.3',
  lgpConditionSource1NeutralScrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.42.4',
  lgpConditionSource2NeutralScrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.42.5',
  lgpConditionFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43',
  lgpConditionFan1Failure => '1.3.6.1.4.1.476.1.42.3.2.1.43.1',
  lgpConditionRedundantFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.2',
  lgpConditionMultipleFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.3',
  lgpConditionBlowerFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.4',
  lgpConditionBottomBlowerFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.4.1',
  lgpConditionTopBlowerFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.4.2',
  lgpConditionCondenserFanVFDFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.5',
  lgpConditionFanPowerFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.6',
  lgpConditionTransferInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.44',
  lgpConditionAutoReTransferPrimed => '1.3.6.1.4.1.476.1.42.3.2.1.45',
  lgpConditionSourcesOutOfSync => '1.3.6.1.4.1.476.1.42.3.2.1.46',
  lgpConditionSourceFailure => '1.3.6.1.4.1.476.1.42.3.2.1.47',
  lgpConditionSource1Failure => '1.3.6.1.4.1.476.1.42.3.2.1.47.1',
  lgpConditionSource2Failure => '1.3.6.1.4.1.476.1.42.3.2.1.47.2',
  lgpConditionAutoReTransferInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.48',
  lgpConditionAutoReTransferFailed => '1.3.6.1.4.1.476.1.42.3.2.1.49',
  lgpConditionFuseOpen => '1.3.6.1.4.1.476.1.42.3.2.1.50',
  lgpConditionControlFuse1Open => '1.3.6.1.4.1.476.1.42.3.2.1.50.1',
  lgpConditionControlFuse2Open => '1.3.6.1.4.1.476.1.42.3.2.1.50.2',
  lgpConditionRectifierFuseOpen => '1.3.6.1.4.1.476.1.42.3.2.1.50.3',
  lgpConditionInverterFuseOpen => '1.3.6.1.4.1.476.1.42.3.2.1.50.4',
  lgpConditionOutputToLoadFuseOpen => '1.3.6.1.4.1.476.1.42.3.2.1.50.5',
  lgpConditionDcCapacitorFuseOpen => '1.3.6.1.4.1.476.1.42.3.2.1.50.6',
  lgpConditionDisconnect => '1.3.6.1.4.1.476.1.42.3.2.1.51',
  lgpConditionSource1DisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.1',
  lgpConditionSource2DisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.2',
  lgpConditionSource1PduDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.3',
  lgpConditionSource2PduDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.4',
  lgpConditionOutputToLoadDisconnect1Open => '1.3.6.1.4.1.476.1.42.3.2.1.51.5',
  lgpConditionOutputToLoadDisconnect2Open => '1.3.6.1.4.1.476.1.42.3.2.1.51.6',
  lgpConditionSource1BypassDisconnectClosed => '1.3.6.1.4.1.476.1.42.3.2.1.51.7',
  lgpConditionSource2BypassDisconnectClosed => '1.3.6.1.4.1.476.1.42.3.2.1.51.8',
  lgpConditionOutputToLoadNeutralDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.9',
  lgpConditionBatteryDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.10',
  lgpConditionBatteryDiscOpenCab01 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.1',
  lgpConditionBatteryDiscOpenCab02 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.2',
  lgpConditionBatteryDiscOpenCab03 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.3',
  lgpConditionBatteryDiscOpenCab04 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.4',
  lgpConditionBatteryDiscOpenCab05 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.5',
  lgpConditionBatteryDiscOpenCab06 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.6',
  lgpConditionBatteryDiscOpenCab07 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.7',
  lgpConditionBatteryDiscOpenCab08 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.8',
  lgpConditionInputDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.11',
  lgpConditionOutputToLoadDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.12',
  lgpConditionBypassDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.13',
  lgpConditionStaticSwitchDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.14',
  lgpConditionBreakerOpenFailure => '1.3.6.1.4.1.476.1.42.3.2.1.51.15',
  lgpConditionBreakerCloseFailure => '1.3.6.1.4.1.476.1.42.3.2.1.51.16',
  lgpConditionFrequencyDeviation => '1.3.6.1.4.1.476.1.42.3.2.1.52',
  lgpConditionSource1FrequencyDeviation => '1.3.6.1.4.1.476.1.42.3.2.1.52.1',
  lgpConditionSource2FrequencyDeviation => '1.3.6.1.4.1.476.1.42.3.2.1.52.2',
  lgpConditionInputFrequencyDeviation => '1.3.6.1.4.1.476.1.42.3.2.1.52.3',
  lgpConditionOutputToLoadFrequencyDeviation => '1.3.6.1.4.1.476.1.42.3.2.1.52.4',
  lgpConditionBypassFrequencyDeviation => '1.3.6.1.4.1.476.1.42.3.2.1.52.5',
  lgpConditionOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53',
  lgpConditionSource1OverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.1',
  lgpConditionSource2OverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.2',
  lgpConditionOutputToLoadOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.3',
  lgpConditionOutputToLoadOverCurrentPhsA => '1.3.6.1.4.1.476.1.42.3.2.1.53.3.1',
  lgpConditionOutputToLoadOverCurrentPhsB => '1.3.6.1.4.1.476.1.42.3.2.1.53.3.2',
  lgpConditionOutputToLoadOverCurrentPhsC => '1.3.6.1.4.1.476.1.42.3.2.1.53.3.3',
  lgpConditionGroundOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.4',
  lgpConditionRectifierOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.5',
  lgpConditionInverterOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.6',
  lgpConditionInverterOverCurrentPhsA => '1.3.6.1.4.1.476.1.42.3.2.1.53.6.1',
  lgpConditionInverterOverCurrentPhsB => '1.3.6.1.4.1.476.1.42.3.2.1.53.6.2',
  lgpConditionInverterOverCurrentPhsC => '1.3.6.1.4.1.476.1.42.3.2.1.53.6.3',
  lgpConditionBatteryConverterOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.7',
  lgpConditionBatteryBalancerOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.8',
  lgpConditionHumidifierOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.9',
  lgpConditionInputOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.10',
  lgpConditionSource1NeutralOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.11',
  lgpConditionSource2NeutralOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.12',
  lgpConditionSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54',
  lgpConditionOutputToLoadVoltageSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.1',
  lgpConditionSource1VoltageSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.2',
  lgpConditionSource2VoltageSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.3',
  lgpConditionSource1ScrSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.4',
  lgpConditionSource2ScrSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.5',
  lgpConditionSource1CurrentSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.6',
  lgpConditionSource2CurrentSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.7',
  lgpConditionRoomTempHumiditySensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.8',
  lgpConditionGlycolTempSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.9',
  lgpConditionLocal1SensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.10',
  lgpConditionCompressor1SensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.11',
  lgpConditionCompressor2SensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.12',
  lgpConditionSupplySensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.13',
  lgpConditionCabinetTemperatureSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.14',
  lgpConditionCabinetHumiditySensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.15',
  lgpConditionRoomTempSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.16',
  lgpConditionBatteryTempSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.17',
  lgpConditionAirSensorAFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.18',
  lgpConditionAirSensorBFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.19',
  lgpConditionChilledWaterSupplySensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.20',
  lgpConditionRefrigerantSupplySensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.21',
  lgpConditionFluidSupplySensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.22',
  lgpConditionCompressorLowPressureSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.23',
  lgpConditionCompressor1LowPressureSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.23.1',
  lgpConditionRemoteSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.24',
  lgpConditionAirSupplyTempSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.25',
  lgpConditionAirReturnTempSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.26',
  lgpConditionCompressorHighPressureSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.27',
  lgpConditionInternalCommunicationFailure => '1.3.6.1.4.1.476.1.42.3.2.1.55',
  lgpConditionExternalCommunicationFailure => '1.3.6.1.4.1.476.1.42.3.2.1.56',
  lgpConditionSourceGateDriveFailure => '1.3.6.1.4.1.476.1.42.3.2.1.57',
  lgpConditionSource1GateDriveFailure => '1.3.6.1.4.1.476.1.42.3.2.1.57.1',
  lgpConditionSource2GateDriveFailure => '1.3.6.1.4.1.476.1.42.3.2.1.57.2',
  lgpConditionDisconnectFailure => '1.3.6.1.4.1.476.1.42.3.2.1.58',
  lgpConditionOutputToLoadNeutralDisconnectFailure => '1.3.6.1.4.1.476.1.42.3.2.1.58.1',
  lgpConditionSource1DisconnectShuntTripFailure => '1.3.6.1.4.1.476.1.42.3.2.1.58.2',
  lgpConditionSource2DisconnectShuntTripFailure => '1.3.6.1.4.1.476.1.42.3.2.1.58.3',
  lgpConditionInverterDisconnectFailure => '1.3.6.1.4.1.476.1.42.3.2.1.58.4',
  lgpConditionBatteryDisconnectFailure => '1.3.6.1.4.1.476.1.42.3.2.1.58.5',
  lgpConditionRectifierDisconnectFailure => '1.3.6.1.4.1.476.1.42.3.2.1.58.6',
  lgpConditionOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59',
  lgpConditionHeatSink1OverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.1',
  lgpConditionAmbient1OverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.2',
  lgpConditionSystemOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.3',
  lgpConditionTransformerOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.4',
  lgpConditionBatteryOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.5',
  lgpConditionRectifierOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.6',
  lgpConditionInverterOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.7',
  lgpConditionRectifierInductorOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.8',
  lgpConditionInverterInductorOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.9',
  lgpConditionBatteryConverterOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.10',
  lgpConditionBatteryBalancerInductorOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.11',
  lgpConditionChilledWaterOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.12',
  lgpConditionElectricHeatersOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.13',
  lgpConditionInletAirOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.14',
  lgpConditionSystemOverTempWarning => '1.3.6.1.4.1.476.1.42.3.2.1.59.15',
  lgpConditionHighTemperatureBattString => '1.3.6.1.4.1.476.1.42.3.2.1.59.16',
  lgpConditionLoadOnAlternateSource => '1.3.6.1.4.1.476.1.42.3.2.1.60',
  lgpConditionPhaseRotationError => '1.3.6.1.4.1.476.1.42.3.2.1.61',
  lgpConditionSource1PhaseRotationError => '1.3.6.1.4.1.476.1.42.3.2.1.61.1',
  lgpConditionSource2PhaseRotationError => '1.3.6.1.4.1.476.1.42.3.2.1.61.2',
  lgpConditionBypassPhaseRotationError => '1.3.6.1.4.1.476.1.42.3.2.1.61.3',
  lgpConditionInputPhaseRotationError => '1.3.6.1.4.1.476.1.42.3.2.1.61.4',
  lgpConditionControlModuleFailure => '1.3.6.1.4.1.476.1.42.3.2.1.62',
  lgpConditionControlModule1Failure => '1.3.6.1.4.1.476.1.42.3.2.1.62.1',
  lgpConditionHistoryLogFull => '1.3.6.1.4.1.476.1.42.3.2.1.63',
  lgpConditionConfigurationModified => '1.3.6.1.4.1.476.1.42.3.2.1.64',
  lgpConditionPasswordModified => '1.3.6.1.4.1.476.1.42.3.2.1.65',
  lgpConditionTimeModified => '1.3.6.1.4.1.476.1.42.3.2.1.66',
  lgpConditionDateModified => '1.3.6.1.4.1.476.1.42.3.2.1.67',
  lgpConditionEventLogCleared => '1.3.6.1.4.1.476.1.42.3.2.1.68',
  lgpConditionHistoryLogCleared => '1.3.6.1.4.1.476.1.42.3.2.1.69',
  lgpConditionUtilityFailure => '1.3.6.1.4.1.476.1.42.3.2.1.70',
  lgpConditionBatteryTestInProgress => '1.3.6.1.4.1.476.1.42.3.2.1.71',
  lgpConditionLoadOnBattery => '1.3.6.1.4.1.476.1.42.3.2.1.72',
  lgpConditionReplaceBattery => '1.3.6.1.4.1.476.1.42.3.2.1.74',
  lgpConditionUpsShutdownPending => '1.3.6.1.4.1.476.1.42.3.2.1.75',
  lgpConditionBatteryChargerFailed => '1.3.6.1.4.1.476.1.42.3.2.1.76',
  lgpConditionBypassVoltageUnqualified => '1.3.6.1.4.1.476.1.42.3.2.1.77',
  lgpConditionCheckAirFilter => '1.3.6.1.4.1.476.1.42.3.2.1.78',
  lgpConditionBrownOut => '1.3.6.1.4.1.476.1.42.3.2.1.79',
  lgpConditionMultipleTransferLockout => '1.3.6.1.4.1.476.1.42.3.2.1.80',
  lgpConditionBypassPhaseLost => '1.3.6.1.4.1.476.1.42.3.2.1.81',
  lgpConditionMaintenceBypassInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.82',
  lgpConditionLoadLockedOnBypass => '1.3.6.1.4.1.476.1.42.3.2.1.83',
  lgpConditionOutputToLoadShort => '1.3.6.1.4.1.476.1.42.3.2.1.84',
  lgpConditionEmergencyTransferToInverter => '1.3.6.1.4.1.476.1.42.3.2.1.85',
  lgpConditonEmergencyPowerOff => '1.3.6.1.4.1.476.1.42.3.2.1.86',
  lgpConditionInverterBackFeed => '1.3.6.1.4.1.476.1.42.3.2.1.87',
  lgpConditionDcGroundFault => '1.3.6.1.4.1.476.1.42.3.2.1.88',
  lgpConditionDcGroundFaultPos => '1.3.6.1.4.1.476.1.42.3.2.1.88.1',
  lgpConditionDcGroundFaultNeg => '1.3.6.1.4.1.476.1.42.3.2.1.88.2',
  lgpConditionStaticTransferSwitchInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.89',
  lgpConditionBatteryLogFullWarning => '1.3.6.1.4.1.476.1.42.3.2.1.90',
  lgpConditionInputCurrentUnbalanced => '1.3.6.1.4.1.476.1.42.3.2.1.91',
  lgpConditionSelfTestFailed => '1.3.6.1.4.1.476.1.42.3.2.1.92',
  lgpConditionInverterOutOfSynchronization => '1.3.6.1.4.1.476.1.42.3.2.1.93',
  lgpConditionModuleAlarm => '1.3.6.1.4.1.476.1.42.3.2.1.94',
  lgpConditioniModuleUnit1Alarm => '1.3.6.1.4.1.476.1.42.3.2.1.94.1',
  lgpConditioniModuleUnit2Alarm => '1.3.6.1.4.1.476.1.42.3.2.1.94.2',
  lgpConditioniModuleUnit3Alarm => '1.3.6.1.4.1.476.1.42.3.2.1.94.3',
  lgpConditioniModuleUnit4Alarm => '1.3.6.1.4.1.476.1.42.3.2.1.94.4',
  lgpConditioniModuleUnit5Alarm => '1.3.6.1.4.1.476.1.42.3.2.1.94.5',
  lgpConditioniModuleUnit6Alarm => '1.3.6.1.4.1.476.1.42.3.2.1.94.6',
  lgpConditioniModuleUnit7Alarm => '1.3.6.1.4.1.476.1.42.3.2.1.94.7',
  lgpConditioniModuleUnit8Alarm => '1.3.6.1.4.1.476.1.42.3.2.1.94.8',
  lgpConditionActiveModuleAlarm => '1.3.6.1.4.1.476.1.42.3.2.1.95',
  lgpConditionControlFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96',
  lgpConditionMainControlFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96.1',
  lgpConditionRedundantControlFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96.2',
  lgpConditionParallelSysControlFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96.3',
  lgpConditionMainControlCommFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96.4',
  lgpConditionControlBoardFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96.5',
  lgpConditionHumidifierControlBdFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96.5.1',
  lgpConditionControlWarning => '1.3.6.1.4.1.476.1.42.3.2.1.97',
  lgpConditionMainControlWarning => '1.3.6.1.4.1.476.1.42.3.2.1.97.1',
  lgpConditionRedundantControlWarning => '1.3.6.1.4.1.476.1.42.3.2.1.97.2',
  lgpConditionUserInterfaceFailure => '1.3.6.1.4.1.476.1.42.3.2.1.98',
  lgpConditionLostPowerRedundancy => '1.3.6.1.4.1.476.1.42.3.2.1.99',
  lgpConditionPowerModuleFailure => '1.3.6.1.4.1.476.1.42.3.2.1.100',
  lgpConditionBatteryModuleFailure => '1.3.6.1.4.1.476.1.42.3.2.1.101',
  lgpConditionOutputToLoadOff => '1.3.6.1.4.1.476.1.42.3.2.1.102',
  lgpConditionSystemOff => '1.3.6.1.4.1.476.1.42.3.2.1.103',
  lgpConditionRectifierStartupFailure => '1.3.6.1.4.1.476.1.42.3.2.1.104',
  lgpConditionRectifierFault => '1.3.6.1.4.1.476.1.42.3.2.1.105',
  lgpConditionInverterShutdownLowDc => '1.3.6.1.4.1.476.1.42.3.2.1.106',
  lgpConditionInverterFault => '1.3.6.1.4.1.476.1.42.3.2.1.107',
  lgpConditionInverterDcOffsetOverrun => '1.3.6.1.4.1.476.1.42.3.2.1.108',
  lgpConditionParallelSysLowBatteryWarning => '1.3.6.1.4.1.476.1.42.3.2.1.109',
  lgpConditionParallelSysLoadShareFault => '1.3.6.1.4.1.476.1.42.3.2.1.110',
  lgpConditionBatteryFault => '1.3.6.1.4.1.476.1.42.3.2.1.111',
  lgpConditionBatteryConverterFailure => '1.3.6.1.4.1.476.1.42.3.2.1.112',
  lgpConditionBatteryBalancerFault => '1.3.6.1.4.1.476.1.42.3.2.1.113',
  lgpConditionpsUpsOperationFault => '1.3.6.1.4.1.476.1.42.3.2.1.114',
  lgpConditionOutputToLoadOnJointMode => '1.3.6.1.4.1.476.1.42.3.2.1.115',
  lgpConditionInputNeutralLost => '1.3.6.1.4.1.476.1.42.3.2.1.116',
  lgpConditionLowBatteryWarning => '1.3.6.1.4.1.476.1.42.3.2.1.117',
  lgpConditionInternalFault => '1.3.6.1.4.1.476.1.42.3.2.1.118',
  lgpConditionBatteryTestFailed => '1.3.6.1.4.1.476.1.42.3.2.1.119',
  lgpConditionPowerModuleWarning => '1.3.6.1.4.1.476.1.42.3.2.1.120',
  lgpConditionBatteryModuleWarning => '1.3.6.1.4.1.476.1.42.3.2.1.121',
  lgpConditionControlModuleWarning => '1.3.6.1.4.1.476.1.42.3.2.1.122',
  lgpConditionUpsOperationFault => '1.3.6.1.4.1.476.1.42.3.2.1.123',
  lgpConditionActiveAlarm => '1.3.6.1.4.1.476.1.42.3.2.1.124',
  lgpConditionRectifierCommunicationFailure => '1.3.6.1.4.1.476.1.42.3.2.1.125',
  lgpConditionInverterCommunicationFailure => '1.3.6.1.4.1.476.1.42.3.2.1.126',
  lgpConditionParallelSysConnectionFault => '1.3.6.1.4.1.476.1.42.3.2.1.127',
  lgpConditionParallelSysCommunicationFailure => '1.3.6.1.4.1.476.1.42.3.2.1.128',
  lgpConditionLostBatteryRedundancy => '1.3.6.1.4.1.476.1.42.3.2.1.129',
  lgpConditionCompPumpDownFailure => '1.3.6.1.4.1.476.1.42.3.2.1.130',
  lgpConditionComp1PumpDownFailure => '1.3.6.1.4.1.476.1.42.3.2.1.130.1',
  lgpConditionComp2PumpDownFailure => '1.3.6.1.4.1.476.1.42.3.2.1.130.2',
  lgpConditionChilledWaterLowWaterFlow => '1.3.6.1.4.1.476.1.42.3.2.1.131',
  lgpConditionAirFilterClogged => '1.3.6.1.4.1.476.1.42.3.2.1.132',
  lgpConditionHumidifierFailure => '1.3.6.1.4.1.476.1.42.3.2.1.133',
  lgpConditionRunHoursExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134',
  lgpConditionUnitRunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.1',
  lgpConditionComp1RunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.2',
  lgpConditionComp2RunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.3',
  lgpConditionFreeCoolRunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.4',
  lgpConditionElectricalHeater1RunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.5',
  lgpConditionElectricalHeater2RunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.6',
  lgpConditionElectricalHeater3RunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.7',
  lgpConditionHotWaterRunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.8',
  lgpConditionHotGasRunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.9',
  lgpConditionHumidifierRunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.10',
  lgpConditionDehumidiferRunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.11',
  lgpConditionFanRunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.12',
  lgpConditionCommWarning => '1.3.6.1.4.1.476.1.42.3.2.1.135',
  lgpConditionCommWarningUnit1 => '1.3.6.1.4.1.476.1.42.3.2.1.135.1',
  lgpConditionCommWarningUnit2 => '1.3.6.1.4.1.476.1.42.3.2.1.135.2',
  lgpConditionCommWarningUnit3 => '1.3.6.1.4.1.476.1.42.3.2.1.135.3',
  lgpConditionCommWarningUnit4 => '1.3.6.1.4.1.476.1.42.3.2.1.135.4',
  lgpConditionCommWarningUnit5 => '1.3.6.1.4.1.476.1.42.3.2.1.135.5',
  lgpConditionCommWarningUnit6 => '1.3.6.1.4.1.476.1.42.3.2.1.135.6',
  lgpConditionCommWarningUnit7 => '1.3.6.1.4.1.476.1.42.3.2.1.135.7',
  lgpConditionCommWarningUnit8 => '1.3.6.1.4.1.476.1.42.3.2.1.135.8',
  lgpConditionCommWarningUnit9 => '1.3.6.1.4.1.476.1.42.3.2.1.135.9',
  lgpConditionCommWarningUnit10 => '1.3.6.1.4.1.476.1.42.3.2.1.135.10',
  lgpConditionCommWarningUnit11 => '1.3.6.1.4.1.476.1.42.3.2.1.135.11',
  lgpConditionCommWarningUnit12 => '1.3.6.1.4.1.476.1.42.3.2.1.135.12',
  lgpConditionCommWarningUnit13 => '1.3.6.1.4.1.476.1.42.3.2.1.135.13',
  lgpConditionCommWarningUnit14 => '1.3.6.1.4.1.476.1.42.3.2.1.135.14',
  lgpConditionCommWarningUnit15 => '1.3.6.1.4.1.476.1.42.3.2.1.135.15',
  lgpConditionCommWarningUnit16 => '1.3.6.1.4.1.476.1.42.3.2.1.135.16',
  lgpConditionUnitOn => '1.3.6.1.4.1.476.1.42.3.2.1.136',
  lgpConditionUnitOff => '1.3.6.1.4.1.476.1.42.3.2.1.137',
  lgpConditionSleepModeOff => '1.3.6.1.4.1.476.1.42.3.2.1.138',
  lgpConditionPowerOn => '1.3.6.1.4.1.476.1.42.3.2.1.139',
  lgpConditionSystemOnStanby => '1.3.6.1.4.1.476.1.42.3.2.1.140',
  lgpConditionPowerOff => '1.3.6.1.4.1.476.1.42.3.2.1.141',
  lgpConditionHighTemperatureGroup => '1.3.6.1.4.1.476.1.42.3.2.1.142',
  lgpConditionHighTemperatureSensor1 => '1.3.6.1.4.1.476.1.42.3.2.1.142.1',
  lgpConditionHighTemperatureDigitalScroll1 => '1.3.6.1.4.1.476.1.42.3.2.1.142.2',
  lgpConditionHighTemperatureDigitalScroll2 => '1.3.6.1.4.1.476.1.42.3.2.1.142.3',
  lgpConditionHighTemperatureUser1 => '1.3.6.1.4.1.476.1.42.3.2.1.142.4',
  lgpConditionHighTemperatureInternal => '1.3.6.1.4.1.476.1.42.3.2.1.142.5',
  lgpConditionHighTemperatureExternalAirSensorA => '1.3.6.1.4.1.476.1.42.3.2.1.142.6',
  lgpConditionHighTemperatureExternalAirSensorB => '1.3.6.1.4.1.476.1.42.3.2.1.142.7',
  lgpConditionHighTemperatureRefrigerantSupply => '1.3.6.1.4.1.476.1.42.3.2.1.142.8',
  lgpConditionHighTemperatureFluidSupply => '1.3.6.1.4.1.476.1.42.3.2.1.142.9',
  lgpConditionHighTemperatureSupplyAir => '1.3.6.1.4.1.476.1.42.3.2.1.142.10',
  lgpConditionHighTemperatureReturnAir => '1.3.6.1.4.1.476.1.42.3.2.1.142.11',
  lgpConditionLowTemperatureGroup => '1.3.6.1.4.1.476.1.42.3.2.1.143',
  lgpConditionLowTemperatureSensor1 => '1.3.6.1.4.1.476.1.42.3.2.1.143.1',
  lgpConditionLowTemperatureInternal => '1.3.6.1.4.1.476.1.42.3.2.1.143.2',
  lgpConditionLowTemperatureExternalAirSensorA => '1.3.6.1.4.1.476.1.42.3.2.1.143.3',
  lgpConditionLowTemperatureExternalAirSensorB => '1.3.6.1.4.1.476.1.42.3.2.1.143.4',
  lgpConditionLowTemperatureRefrigerantSupply => '1.3.6.1.4.1.476.1.42.3.2.1.143.5',
  lgpConditionLowTemperatureFluidSupply => '1.3.6.1.4.1.476.1.42.3.2.1.143.6',
  lgpConditionLowTemperatureSupplyAir => '1.3.6.1.4.1.476.1.42.3.2.1.143.7',
  lgpConditionHighHumidityGroup => '1.3.6.1.4.1.476.1.42.3.2.1.144',
  lgpConditionHighHumiditySensor1 => '1.3.6.1.4.1.476.1.42.3.2.1.144.1',
  lgpConditionHighHumidityReturnAir => '1.3.6.1.4.1.476.1.42.3.2.1.144.2',
  lgpConditionLowHumidityGroup => '1.3.6.1.4.1.476.1.42.3.2.1.145',
  lgpConditionLowHumiditySensor1 => '1.3.6.1.4.1.476.1.42.3.2.1.145.1',
  lgpConditionLowHumidityReturnAir => '1.3.6.1.4.1.476.1.42.3.2.1.145.2',
  lgpConditionPeerNetworkNoMaster => '1.3.6.1.4.1.476.1.42.3.2.1.146',
  lgpConditionNoOnOffPermissions => '1.3.6.1.4.1.476.1.42.3.2.1.147',
  lgpConditionPeerNetworkFailure => '1.3.6.1.4.1.476.1.42.3.2.1.148',
  lgpConditionUnitDisabled => '1.3.6.1.4.1.476.1.42.3.2.1.149',
  lgpConditionUnitShutdown => '1.3.6.1.4.1.476.1.42.3.2.1.150',
  lgpConditionPeerNetworkDiscovered => '1.3.6.1.4.1.476.1.42.3.2.1.151',
  lgpConditionLossOfWaterFlow => '1.3.6.1.4.1.476.1.42.3.2.1.152',
  lgpConditionCondensatePumpHighWater => '1.3.6.1.4.1.476.1.42.3.2.1.153',
  lgpConditionGeneralAlarm => '1.3.6.1.4.1.476.1.42.3.2.1.154',
  lgpConditionProductSpecific => '1.3.6.1.4.1.476.1.42.3.2.1.155',
  lgpConditionReheatLockout => '1.3.6.1.4.1.476.1.42.3.2.1.156',
  lgpConditionHumidifierLockout => '1.3.6.1.4.1.476.1.42.3.2.1.157',
  lgpConditionCompressorsLockout => '1.3.6.1.4.1.476.1.42.3.2.1.158',
  lgpConditionCallService => '1.3.6.1.4.1.476.1.42.3.2.1.159',
  lgpConditionLowMemoryGroup => '1.3.6.1.4.1.476.1.42.3.2.1.160',
  lgpConditionLowMemory1 => '1.3.6.1.4.1.476.1.42.3.2.1.160.1',
  lgpConditionMemoryFailureGroup => '1.3.6.1.4.1.476.1.42.3.2.1.161',
  lgpConditionMemory1Failure => '1.3.6.1.4.1.476.1.42.3.2.1.161.1',
  lgpConditionMemory2Failure => '1.3.6.1.4.1.476.1.42.3.2.1.161.2',
  lgpConditionUnitCodeErrorGroup => '1.3.6.1.4.1.476.1.42.3.2.1.162',
  lgpConditionUnitCodeNotConfigured => '1.3.6.1.4.1.476.1.42.3.2.1.162.1',
  lgpConditionUnitCode01OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.2',
  lgpConditionUnitCode02OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.3',
  lgpConditionUnitCode03OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.4',
  lgpConditionUnitCode04OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.5',
  lgpConditionUnitCode05OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.6',
  lgpConditionUnitCode06OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.7',
  lgpConditionUnitCode07OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.8',
  lgpConditionUnitCode08OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.9',
  lgpConditionUnitCode09OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.10',
  lgpConditionUnitCode10OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.11',
  lgpConditionUnitCode11OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.12',
  lgpConditionUnitCode12OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.13',
  lgpConditionUnitCode13OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.14',
  lgpConditionUnitCode14OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.15',
  lgpConditionUnitCode15OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.16',
  lgpConditionUnitCode16OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.17',
  lgpConditionUnitCode17OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.18',
  lgpConditionUnitCode18OutOfRange => '1.3.6.1.4.1.476.1.42.3.2.1.162.19',
  lgpConditionHighExternalDewPoint => '1.3.6.1.4.1.476.1.42.3.2.1.163',
  lgpConditionHcbDisconnected => '1.3.6.1.4.1.476.1.42.3.2.1.164',
  lgpConditionBmsResetTimerExpired => '1.3.6.1.4.1.476.1.42.3.2.1.165',
  lgpConditionAgentFirmwareCorrupt => '1.3.6.1.4.1.476.1.42.3.2.1.166',
  lgpConditionSystemAccessGroup => '1.3.6.1.4.1.476.1.42.3.2.1.175',
  lgpConditionFrontAccessOpen => '1.3.6.1.4.1.476.1.42.3.2.1.175.1',
  lgpConditionRearAccessOpen => '1.3.6.1.4.1.476.1.42.3.2.1.175.2',
  lgpConditionsDamperFailure => '1.3.6.1.4.1.476.1.42.3.2.1.176',
  lgpConditionEmergencyDamperFailure => '1.3.6.1.4.1.476.1.42.3.2.1.176.1',
  lgpConditionRemoteShutdown => '1.3.6.1.4.1.476.1.42.3.2.1.177',
  lgpConditionFireAlarm => '1.3.6.1.4.1.476.1.42.3.2.1.178',
  lgpConditionHeatersOverheated => '1.3.6.1.4.1.476.1.42.3.2.1.179',
  lgpConditionCondenserFailureGroup => '1.3.6.1.4.1.476.1.42.3.2.1.180',
  lgpConditionCondenser1Failure => '1.3.6.1.4.1.476.1.42.3.2.1.180.1',
  lgpConditionCondenser2Failure => '1.3.6.1.4.1.476.1.42.3.2.1.180.2',
  lgpConditionCondenserTVSSFailure => '1.3.6.1.4.1.476.1.42.3.2.1.180.3',
  lgpConditionHumidifierCyclinderWorn => '1.3.6.1.4.1.476.1.42.3.2.1.181',
  lgpConditionUnderCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.182',
  lgpConditionHumidifierUnderCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.182.1',
  lgpConditionInputUnderCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.182.2',
  lgpConditionHeatRejectorGroup => '1.3.6.1.4.1.476.1.42.3.2.1.183',
  lgpConditionHeatRejectorFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.183.1',
  lgpConditionHeatRejectorVoltageSuppressionFailure => '1.3.6.1.4.1.476.1.42.3.2.1.183.2',
  lgpConditionFreeCoolLockout => '1.3.6.1.4.1.476.1.42.3.2.1.184',
  lgpConditionWaterLeakSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.185',
  lgpConditionNoLoadDetectedWarning => '1.3.6.1.4.1.476.1.42.3.2.1.186',
  lgpConditionFirmwareGroup => '1.3.6.1.4.1.476.1.42.3.2.1.187',
  lgpConditionFirmwareUpdateRequired => '1.3.6.1.4.1.476.1.42.3.2.1.187.3',
  lgpConditionTestGroup => '1.3.6.1.4.1.476.1.42.3.2.1.188',
  lgpConditionTest01 => '1.3.6.1.4.1.476.1.42.3.2.1.188.5',
  lgpConditionReceptacleBranchGroup => '1.3.6.1.4.1.476.1.42.3.2.1.190',
  lgpConditionRcpBranchFailure => '1.3.6.1.4.1.476.1.42.3.2.1.190.5',
  lgpConditionRcpBranchBreakerOpen => '1.3.6.1.4.1.476.1.42.3.2.1.190.10',
  lgpConditionInputUnqualified => '1.3.6.1.4.1.476.1.42.3.2.1.192',
  lgpConditionBypassUnavailable => '1.3.6.1.4.1.476.1.42.3.2.1.193',
  lgpConditionAutoTransferFailed => '1.3.6.1.4.1.476.1.42.3.2.1.194',
  lgpConditionSBSUnavailable => '1.3.6.1.4.1.476.1.42.3.2.1.195',
  lgpConditionSBSOverload => '1.3.6.1.4.1.476.1.42.3.2.1.196',
  lgpConditionExcessPulseParallel => '1.3.6.1.4.1.476.1.42.3.2.1.197',
  lgpConditionRemoteBypassSwitchOffExt => '1.3.6.1.4.1.476.1.42.3.2.1.198',
  lgpConditionManTransferInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.199',
  lgpConditionManReTransferInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.200',
  lgpConditionBatteryChargeError => '1.3.6.1.4.1.476.1.42.3.2.1.201',
  lgpConditionBatteryAutoTestInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.202',
  lgpConditionBatteryChargeReducedExt => '1.3.6.1.4.1.476.1.42.3.2.1.203',
  lgpConditionBatteryCapacityLow => '1.3.6.1.4.1.476.1.42.3.2.1.204',
  lgpConditionBatteryTempImbalance => '1.3.6.1.4.1.476.1.42.3.2.1.205',
  lgpConditionBatteryEqualize => '1.3.6.1.4.1.476.1.42.3.2.1.206',
  lgpConditionBatteryChargeInhibitedExt => '1.3.6.1.4.1.476.1.42.3.2.1.207',
  lgpConditionServiceExtBatteryMonitorGroup => '1.3.6.1.4.1.476.1.42.3.2.1.208',
  lgpConditionServiceExtBatteryMonitor1 => '1.3.6.1.4.1.476.1.42.3.2.1.208.1',
  lgpConditionServiceExtBatteryMonitor2 => '1.3.6.1.4.1.476.1.42.3.2.1.208.2',
  lgpConditionBatteryGroundFault => '1.3.6.1.4.1.476.1.42.3.2.1.209',
  lgpConditionBatteryLowShutdown => '1.3.6.1.4.1.476.1.42.3.2.1.210',
  lgpConditionEmergencyPowerOffLocal => '1.3.6.1.4.1.476.1.42.3.2.1.211',
  lgpConditionOutputLowPFLagging => '1.3.6.1.4.1.476.1.42.3.2.1.212',
  lgpConditionOutputLowPFLeading => '1.3.6.1.4.1.476.1.42.3.2.1.213',
  lgpConditionOutputToLoadFault => '1.3.6.1.4.1.476.1.42.3.2.1.214',
  lgpConditionInvRestartInhibitedExt => '1.3.6.1.4.1.476.1.42.3.2.1.215',
  lgpConditionInverterShutdownOverload => '1.3.6.1.4.1.476.1.42.3.2.1.216',
  lgpConditionInverterOffExt => '1.3.6.1.4.1.476.1.42.3.2.1.217',
  lgpConditionInputContactGroup => '1.3.6.1.4.1.476.1.42.3.2.1.218',
  lgpConditionInputContact01 => '1.3.6.1.4.1.476.1.42.3.2.1.218.1',
  lgpConditionInputContact02 => '1.3.6.1.4.1.476.1.42.3.2.1.218.2',
  lgpConditionInputContact03 => '1.3.6.1.4.1.476.1.42.3.2.1.218.3',
  lgpConditionInputContact04 => '1.3.6.1.4.1.476.1.42.3.2.1.218.4',
  lgpConditionInputContact05 => '1.3.6.1.4.1.476.1.42.3.2.1.218.5',
  lgpConditionInputContact06 => '1.3.6.1.4.1.476.1.42.3.2.1.218.6',
  lgpConditionInputContact07 => '1.3.6.1.4.1.476.1.42.3.2.1.218.7',
  lgpConditionInputContact08 => '1.3.6.1.4.1.476.1.42.3.2.1.218.8',
  lgpConditionInputContact09 => '1.3.6.1.4.1.476.1.42.3.2.1.218.9',
  lgpConditionInputContact10 => '1.3.6.1.4.1.476.1.42.3.2.1.218.10',
  lgpConditionInputContact11 => '1.3.6.1.4.1.476.1.42.3.2.1.218.11',
  lgpConditionInputContact12 => '1.3.6.1.4.1.476.1.42.3.2.1.218.12',
  lgpConditionInputContact13 => '1.3.6.1.4.1.476.1.42.3.2.1.218.13',
  lgpConditionInputContact14 => '1.3.6.1.4.1.476.1.42.3.2.1.218.14',
  lgpConditionInputContact15 => '1.3.6.1.4.1.476.1.42.3.2.1.218.15',
  lgpConditionInputContact16 => '1.3.6.1.4.1.476.1.42.3.2.1.218.16',
  lgpConditionRectifierOperInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.219',
  lgpConditionBypassBackFeedBrkrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.220',
  lgpConditionAutoRestartInProgress => '1.3.6.1.4.1.476.1.42.3.2.1.221',
  lgpConditionAutoRestartInhibitedExt => '1.3.6.1.4.1.476.1.42.3.2.1.222',
  lgpConditionAutoRestartFailed => '1.3.6.1.4.1.476.1.42.3.2.1.223',
  lgpConditionInputOnGenerator => '1.3.6.1.4.1.476.1.42.3.2.1.224',
  lgpConditionInputFilterCycleLock => '1.3.6.1.4.1.476.1.42.3.2.1.225',
  lgpConditionServiceCodeActive => '1.3.6.1.4.1.476.1.42.3.2.1.226',
  lgpConditionLoadBusSyncActive => '1.3.6.1.4.1.476.1.42.3.2.1.227',
  lgpConditionLoadBusSyncInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.228',
  lgpConditionControlsResetRequired => '1.3.6.1.4.1.476.1.42.3.2.1.229',
  lgpConditionEquipTempSensorFailed => '1.3.6.1.4.1.476.1.42.3.2.1.230',
  lgpConditionInputCurrentImbalance => '1.3.6.1.4.1.476.1.42.3.2.1.231',
  lgpConditionPumpGroup => '1.3.6.1.4.1.476.1.42.3.2.1.232',
  lgpConditionPumpFlowLoss => '1.3.6.1.4.1.476.1.42.3.2.1.232.1',
  lgpConditionPump1FlowLoss => '1.3.6.1.4.1.476.1.42.3.2.1.232.1.1',
  lgpConditionPump2FlowLoss => '1.3.6.1.4.1.476.1.42.3.2.1.232.1.2',
  lgpConditionPumpShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.232.2',
  lgpConditionPumpInverterShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.232.3',
  lgpConditionPump1InverterShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.232.3.1',
  lgpConditionPump2InverterShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.232.3.2',
  lgpConditionValveGroup => '1.3.6.1.4.1.476.1.42.3.2.1.233',
  lgpConditionChilledWaterValvePosition => '1.3.6.1.4.1.476.1.42.3.2.1.233.1',
  lgpConditionCondensationDetected => '1.3.6.1.4.1.476.1.42.3.2.1.234',
  lgpConditionMaintenanceGroup => '1.3.6.1.4.1.476.1.42.3.2.1.235',
  lgpConditionMaintenanceDue => '1.3.6.1.4.1.476.1.42.3.2.1.235.1',
  lgpConditionMaintenanceComplete => '1.3.6.1.4.1.476.1.42.3.2.1.235.2',
  lgpConditionExternalEventSignalGroup => '1.3.6.1.4.1.476.1.42.3.2.1.236',
  lgpConditionExternalFireDetect => '1.3.6.1.4.1.476.1.42.3.2.1.236.1',
  lgpConditionExternalFlowLoss => '1.3.6.1.4.1.476.1.42.3.2.1.236.2',
  lgpConditionExternalReheatLockout => '1.3.6.1.4.1.476.1.42.3.2.1.236.3',
  lgpConditionExternalOverTemp => '1.3.6.1.4.1.476.1.42.3.2.1.236.4',
  lgpConditionExternalCompLockout => '1.3.6.1.4.1.476.1.42.3.2.1.236.5',
  lgpConditionExternalHumidifierLockout => '1.3.6.1.4.1.476.1.42.3.2.1.236.6',
  lgpConditionComponentShutdownGroup => '1.3.6.1.4.1.476.1.42.3.2.1.237',
  lgpConditionComponentShutdownPartial => '1.3.6.1.4.1.476.1.42.3.2.1.237.1',
  lgpConditionComponentShutdownHighPower => '1.3.6.1.4.1.476.1.42.3.2.1.237.2',
  lgpConditionCondenserProblemGroup => '1.3.6.1.4.1.476.1.42.3.2.1.238',
  lgpConditionCondenser1Problem => '1.3.6.1.4.1.476.1.42.3.2.1.238.1',
  lgpConditionHumidityOutOfPropBand => '1.3.6.1.4.1.476.1.42.3.2.1.239',
  lgpConditionEnvRemoteSensorGroup => '1.3.6.1.4.1.476.1.42.3.2.1.240',
  lgpConditionEnvRemoteSensor1Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.1',
  lgpConditionEnvRemoteSensor2Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.2',
  lgpConditionEnvRemoteSensor3Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.3',
  lgpConditionEnvRemoteSensor4Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.4',
  lgpConditionEnvRemoteSensor5Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.5',
  lgpConditionEnvRemoteSensor6Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.6',
  lgpConditionEnvRemoteSensor7Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.7',
  lgpConditionEnvRemoteSensor8Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.8',
  lgpConditionEnvRemoteSensor9Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.9',
  lgpConditionEnvRemoteSensor10Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.10',
  lgpConditionNeutralSnubberBoardCommFailure => '1.3.6.1.4.1.476.1.42.3.2.1.241',
  lgpConditionRedundantChargerFailure => '1.3.6.1.4.1.476.1.42.3.2.1.242',
  lgpConditionBoardInputContactorPowerFailure => '1.3.6.1.4.1.476.1.42.3.2.1.243',
  lgpConditionBoard1InputContactorPowerFailure => '1.3.6.1.4.1.476.1.42.3.2.1.243.1',
  lgpConditionBoard2InputContactorPowerFailure => '1.3.6.1.4.1.476.1.42.3.2.1.243.2',
  lgpConditionTooManySensors => '1.3.6.1.4.1.476.1.42.3.2.1.5423',
  lgpConditionDoorSwitchOpen => '1.3.6.1.4.1.476.1.42.3.2.1.5471',
  lgpConditionContactClosureOpen => '1.3.6.1.4.1.476.1.42.3.2.1.5479',
  lgpConditionContactClosureClosed => '1.3.6.1.4.1.476.1.42.3.2.1.5480',
  lgpConditionsPresent => '1.3.6.1.4.1.476.1.42.3.2.2',
  lgpConditionsTable => '1.3.6.1.4.1.476.1.42.3.2.3',
  lgpConditionsEntry => '1.3.6.1.4.1.476.1.42.3.2.3.1', # dummy /Table/Entry/
  lgpConditionEntry => '1.3.6.1.4.1.476.1.42.3.2.3.1',
  lgpConditionId => '1.3.6.1.4.1.476.1.42.3.2.3.1.1',
  lgpConditionDescr => '1.3.6.1.4.1.476.1.42.3.2.3.1.2',
  lgpConditionTime => '1.3.6.1.4.1.476.1.42.3.2.3.1.3',
  lgpConditionTableRef => '1.3.6.1.4.1.476.1.42.3.2.3.1.5',
  lgpConditionTableRowRef => '1.3.6.1.4.1.476.1.42.3.2.3.1.6',
  lgpConditionType => '1.3.6.1.4.1.476.1.42.3.2.3.1.10',
  lgpConditionTypeDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionType',
  lgpConditionCurrentState => '1.3.6.1.4.1.476.1.42.3.2.3.1.12',
  lgpConditionCurrentStateDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionCurrentState',
  lgpConditionSeverity => '1.3.6.1.4.1.476.1.42.3.2.3.1.14',
  lgpConditionSeverityDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionSeverity',
  lgpConditionAcknowledged => '1.3.6.1.4.1.476.1.42.3.2.3.1.18',
  lgpConditionAcknowledgedDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionAcknowledged',
  lgpConditionAckReq => '1.3.6.1.4.1.476.1.42.3.2.3.1.19',
  lgpConditionAckReqDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionAckReq',
  lgpConditionControl => '1.3.6.1.4.1.476.1.42.3.2.4',
  lgpConditionControlEventReset => '1.3.6.1.4.1.476.1.42.3.2.4.1',
  lgpConditionControlEventResetDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionControlEventReset',
  lgpConditionControlEventAck => '1.3.6.1.4.1.476.1.42.3.2.4.2',
  lgpConditionControlEventAckDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionControlEventAck',
  lgpConditionControlTable => '1.3.6.1.4.1.476.1.42.3.2.4.20',
  lgpConditionControlEntry => '1.3.6.1.4.1.476.1.42.3.2.4.20.1',
  lgpConditionControlIndex => '1.3.6.1.4.1.476.1.42.3.2.4.20.1.1',
  lgpConditionControlDescr => '1.3.6.1.4.1.476.1.42.3.2.4.20.1.2',
  lgpConditionControlEnableStatus => '1.3.6.1.4.1.476.1.42.3.2.4.20.1.3',
  lgpConditionControlEnableStatusDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionControlEnableStatus',
  lgpConditionControlType => '1.3.6.1.4.1.476.1.42.3.2.4.20.1.4',
  lgpConditionControlTypeDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionControlType',
  lgpConditionControlEnableCapability => '1.3.6.1.4.1.476.1.42.3.2.4.20.1.5',
  lgpConditionControlEnableCapabilityDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionControlEnableCapability',
  lgpConditionDescription => '1.3.6.1.4.1.476.1.42.3.2.5',
  lgpNetworkName => '1.3.6.1.4.1.476.1.42.3.2.6',
  lgpFlexConditions => '1.3.6.1.4.1.476.1.42.3.2.7',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'LIEBERT-GP-CONDITIONS-MIB'} = {
  lgpConditionCurrentState => {
    '1' => 'active',
    '2' => 'inactive',
  },
  lgpConditionType => {
    '0' => 'not-specified',
    '2' => 'message',
    '4' => 'warning',
    '6' => 'alarm',
    '8' => 'fault',
  },
  lgpConditionControlEventAck => {
    '1' => 'noAction',
    '2' => 'ackAll',
  },
  lgpConditionAcknowledged => {
    '1' => 'notAcknowledged',
    '2' => 'acknowledged',
  },
  lgpConditionSeverity => {
    '0' => 'not-applicable',
    '3' => 'minor',
    '6' => 'major',
    '9' => 'critical',
  },
  lgpConditionControlEventReset => {
    '1' => 'noAction',
    '2' => 'resetAll',
  },
  lgpConditionControlEnableCapability => {
    '0' => 'not-specified',
    '1' => 'read-only',
    '2' => 'read-write',
  },
  lgpConditionAckReq => {
    '1' => 'required',
    '2' => 'notRequired',
  },
  lgpConditionControlType => {
    '0' => 'not-specified',
    '2' => 'message',
    '4' => 'warning',
    '6' => 'alarm',
    '8' => 'fault',
  },
  lgpConditionControlEnableStatus => {
    '0' => 'not-specified',
    '1' => 'enabled',
    '2' => 'disabled',
  },
};
